#!/usr/bin/perl -w

use strict;

BEGIN {
	use lib qw( t/ );
	print "1..6\n";
}

use object_list;

require 'recreate_tables.pl';

my $t = 1;
my ($h, $s, $err);

##-----  initial save with single inheritance  -----
## create initialized Helicopter
$h = Helicopter->new( {	name			=> 'Whirly Bird',
						owner			=> 25,
						ceiling			=> 7500,
						lift_capacity	=> 800
					} );
my $hid = $h->save->id;
## check that we can get back the same thing
print "not "	unless $h->compare(Helicopter->fetch($h->id));
print "ok @{[ $t++ ]}\n";

##-----  initial save with multiple inheritance  -----
## create initialized Seaplane
$s = Seaplane->new( {	name			=> 'PuddleJumper',
						owner			=> 20,
						ceiling			=> 9000,
						wingspan		=> 36,
						min_depth		=> 2.5,
						anchor			=> Anchor->new({weight => 25}),
						max_wave_height	=> 2
					} );

my $sid = $s->save->id;
## check that we can get back the same thing
print "not "	unless $s->compare(Seaplane->fetch($s->id));
print "ok @{[ $t++ ]}\n";

##-----  update save with single inheritance  -----
$h->{ceiling} = 10000;
$h->save;
print "not "	unless $h->compare(Helicopter->fetch($h->id));
print "ok @{[ $t++ ]}\n";

##-----  update save with multiple inheritance  -----
$s->{min_depth} = 3.5;
$s->save;
print "not "	unless $s->compare(Seaplane->fetch($s->id));
print "ok @{[ $t++ ]}\n";

##-----  explicit is_add save with single inheritance  -----
my $h2 = Helicopter->fetch($h->id);
$h2->remove;
$h->save( {is_add => 1} );
print "not "	unless $h->compare(Helicopter->fetch($h->id));
print "ok @{[ $t++ ]}\n";

##-----  explicit is_add save with multiple inheritance  -----
my $s2 = Seaplane->fetch($s->id);
$s2->remove;
$s->{anchor} = undef;
$s->save( {is_add => 1} );
print "not "	unless $s->compare(Seaplane->fetch($s->id));
print "ok @{[ $t++ ]}\n";

1;
