#!/usr/bin/perl -w

use strict;

BEGIN {
	use lib qw( t/ );
	print "1..11\n";
}

use object_list;

require 'recreate_tables.pl';
require 'fill_tables.pl';

my $t = 1;
my ($err, $v, $p, $s, $a, $by, $slips);

##-----  fetch method  -----
$v = Vehicle->fetch(1);
$p = $v->owner_PersonAlias;
print "not "	unless ref($p) eq 'Person' && $p->id == 24;
print "ok @{[ $t++ ]}\n";

##-----  forward direction auto-fetching  -----
$s = Seaplane->fetch(12);
$a = $s->{anchor};
print "not "	unless ref($a) eq 'Anchor' && $a->id == 17;
print "ok @{[ $t++ ]}\n";

##-----  backward direction auto-fetching  -----
$by = Boatyard->fetch(30);
$slips = $by->{list_of_slips};
$err = 3;
foreach $s (@$slips) {
	if ($s->id == 34)  { $err--; next; }
	if ($s->id == 35)  { $err--; next; }
	if ($s->id == 36)  { $err--; next; }
	$err++;
}
print "not "	if $err;
print "ok @{[ $t++ ]}\n";

##-----  forward direction auto-fetching  -----
$s = Seaplane->fetch(12);
$a = $s->{anchor};
print "not "	unless ref($a) eq 'Anchor' && $a->id == 17;
print "ok @{[ $t++ ]}\n";

##-----  backward direction auto-fetching  -----
$by = Boatyard->fetch(30);
$slips = $by->{list_of_slips};
$err = 3;
foreach $s (@$slips) {
	if (ref $s eq 'Slip' && $s->id == 34)  { $err--; next; }
	if (ref $s eq 'Slip' && $s->id == 35)  { $err--; next; }
	if (ref $s eq 'Slip' && $s->id == 36)  { $err--; next; }
	$err++;
}
print "not "	if $err;
print "ok @{[ $t++ ]}\n";

##-----  forward direction auto-save  -----
## save with id in anchor field
$a = Anchor->new({weight => 200});
$a->save;
$s = Seaplane->new( {	name			=> 'Albatross',
						owner			=> 17,
						ceiling			=> 19000,
						wingspan		=> 50,
						min_depth		=> 10,
						anchor			=> $a->id,
						max_wave_height	=> 4
					} );
$s->save;
$a = $s->{anchor};
print "not "	unless ref($a) eq 'Anchor' && Anchor->fetch($a->id)->weight == 200;
print "ok @{[ $t++ ]}\n";

## save with object in anchor field
$s->remove;
$s = Seaplane->new( {	name			=> 'Albatross',
						owner			=> 17,
						ceiling			=> 19000,
						wingspan		=> 50,
						min_depth		=> 10,
						anchor			=> Anchor->new({weight => 250}),
						max_wave_height	=> 4
					} );
$s->save;
$a = $s->{anchor};
print "not "	unless ref($a) eq 'Anchor' && Anchor->fetch($a->id)->weight == 250;
print "ok @{[ $t++ ]}\n";

##-----  backward direction auto-save  -----
$by = Boatyard->new( { name => 'Dock City'} );
$by->{list_of_slips} = 	[	Slip->new( {number => 1} ),
							Slip->new( {number => 2} ),
							Slip->new( {number => 3} ),
							Slip->new( {number => 4} )
						];
$by->save;
$slips = $by->{list_of_slips};
$err = 4;
foreach $s (@$slips) {
	if ($s->number == 1)  { $err-- if $s->{boatyard} == $by->id; next; }
	if ($s->number == 2)  { $err-- if $s->{boatyard} == $by->id; next; }
	if ($s->number == 3)  { $err-- if $s->{boatyard} == $by->id; next; }
	if ($s->number == 4)  { $err-- if $s->{boatyard} == $by->id; next; }
	$err++;
}
print "not "	if $err;
print "ok @{[ $t++ ]}\n";
$by = Boatyard->fetch($by->id);
$slips = $by->{list_of_slips};
$err = 4;
foreach $s (@$slips) {
	if ($s->number == 1)  { $err--; next; }
	if ($s->number == 2)  { $err--; next; }
	if ($s->number == 3)  { $err--; next; }
	if ($s->number == 4)  { $err--; next; }
	$err++;
}
print "not "	if $err;
print "ok @{[ $t++ ]}\n";

##-----  forward direction auto-remove  -----
my ($args, $row);
$s->remove;
$args = {	from => [ Anchor->base_table ],
			select => [ 'count(*)'],
			where => Anchor->id_clause($a->id, undef, undef),
			return => 'single'
		};
$row = eval { Anchor->db_select($args);	};
print "not "	if $row->[0];
print "ok @{[ $t++ ]}\n";

##-----  backward direction auto-remove  -----
$by->remove;
$args = {	from => [ Slip->base_table ],
			select => [ 'count(*)'],
			where => 'boatyard = ' . $by->id,
			return => 'single'
		};
$row = eval { Slip->db_select($args);	};
print "not "	if $row->[0];
print "ok @{[ $t++ ]}\n";

1;
