package Boat;

use strict;
use vars qw($VERSION @ISA $CONF $TABLE_DEF %HASA_CLASS);

BEGIN {
	$VERSION = sprintf "%d.%03d", q$Revision: 1.15 $ =~ /: (\d+)\.(\d+)/;
	@ISA = qw/ Vehicle /;
	$CONF = {
		BoatAlias => {
			class			=> 'Boat',
			isa				=> \@ISA,
			field			=> [ qw/ id min_depth anchor / ],
			as_string_order => [ qw/ id class name owner min_depth anchor / ],
			base_table		=> 'Boat',
			has_a			=> { 'Anchor' => [ 'anchor' ] },
			id_field		=> 'id',
			skip_undef		=> [ qw/ min_depth anchor / ],
			no_security		=> 1,
		},
	};
	$TABLE_DEF = <<SQL;
CREATE TABLE Boat (
	id       int(11) PRIMARY KEY,
	min_depth numeric(10,2),
	anchor  int(11)
)
SQL
	%HASA_CLASS =  ('anchor' => 'Anchor');
}

use Vehicle;
use Anchor;

sub remove_barnacles {
	my $this = shift;
	print "Barnacles removed from " . $this->{name} . "\n"; 
}

sub pre_save_action {

	my $self = shift;
	my $p = shift;
	$self->SUPER::pre_save_action({%$p});
	if (ref($self) eq __PACKAGE__) {
		$self->_handle_action('presave',{%$p});
	}

	return $self;
}

sub post_save_action {

	my $self = shift;
	my $p = shift;
	$self->SUPER::post_save_action({%$p});
	if (ref($self) eq __PACKAGE__) {
		$self->_handle_action('postsave',{%$p});
	}
	return $self;
}

sub post_fetch_action {

	my $self = shift;
	my $p = shift;
	$self->SUPER::post_fetch_action({%$p});		
	$self->_handle_action('postfetch',{%$p});
	return $self;
}

sub pre_remove_action {
	
	my $self = shift;
	my $p = shift;
	$self->SUPER::pre_remove_action({%$p});
	$self->_handle_action('preremove',{%$p});
	return $self ;
}

sub _handle_action {

	my $self = shift;
	my $action = shift || '';
	my $p = shift || undef;

	return $self unless $action;
	
	while(my ($hasa_id_field, $hasa_class) = each %HASA_CLASS){ # anchor => 'Anchor'
		# get the temp variable . eg : anchor_var
		my $temp_var = $hasa_id_field . '_var';
		
		SWITCH :  {
			if ($action eq 'presave'){
				# get the id
				my $hobj_id = $self->{$hasa_id_field} || last SWITCH;
				if (ref $hobj_id eq $hasa_class){
					$self->{$temp_var} = $hobj_id;
					$self->{$hasa_id_field} = $hobj_id->saved ? $hobj_id->id : $hobj_id->save($p)->id;
				}
				last SWITCH;
			}
			if ($action eq 'postsave'){
				# do not let in if self->{hasa_id_field} is undefined or correct object
				if (defined $self->{$hasa_id_field}){
					# get the object from temp_var if it is correct object
					if (ref $self->{$temp_var} eq $hasa_class){
						$self->{$hasa_id_field} = $self->{$temp_var};
					}else{	#fetch it using the classname->fetch(id) method 
						$self->{$hasa_id_field} = $hasa_class->fetch($self->{$hasa_id_field},{%$p});
						die "$!" unless(defined $self->{$hasa_id_field});
					}
				}
				delete $self->{$temp_var} if $self->{$temp_var};
				last SWITCH;
			}
			if ($action eq 'postfetch'){
				$self->{$hasa_id_field} = $hasa_class->fetch($self->{$hasa_id_field},$p)
					 if $self->{$hasa_id_field};
				last SWITCH;
			}
			if ($action eq 'preremove'){
				unless (ref($self->{$hasa_id_field}) eq $hasa_class){
					## attempt to fetch the object so we can delete it
					 if ($self->{$hasa_id_field}){
						$self->{$hasa_id_field} = $hasa_class->fetch($self->{$hasa_id_field},$p);
						die "$!" unless $self->{$hasa_id_field}->remove($p);
					 } 
				}
				if (ref($self->{$hasa_id_field}) eq $hasa_class) {
					warn "Error in pre_remove_action in Boat.pm" 
							unless($self->{$hasa_id_field}->remove($p));
				}
				last SWITCH;
			} 
		}#end SWITCH
	}#end while
	return $self;
}

__PACKAGE__->config_and_init;

1;
